==> mir_0.21.0+16.04.20160330.orig.tar.gz: include/server/mir/frontend/session.h <==
/*
 * Copyright © 2012 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored By: Robert Carr <racarr@canonical.com>
 */

#ifndef MIR_FRONTEND_SESSION_H_
#define MIR_FRONTEND_SESSION_H_

#include "mir_toolkit/common.h"
#include "mir/frontend/surface_id.h"
#include "mir/frontend/buffer_stream_id.h"

#include <memory>
#include <string>

namespace mir
{
namespace graphics
{
class DisplayConfiguration;
struct BufferProperties;
}

namespace frontend
{
class Surface;
class BufferStream;

class Session
{
public:
    virtual ~Session() = default;

    virtual std::shared_ptr<Surface> get_surface(SurfaceId surface) const = 0;

    virtual std::shared_ptr<BufferStream> get_buffer_stream(BufferStreamId stream) const = 0;
    virtual BufferStreamId create_buffer_stream(graphics::BufferProperties const& props) = 0;
    virtual void destroy_buffer_stream(BufferStreamId stream) = 0;

    virtual std::string name() const = 0;

protected:
    Session() = default;
    Session(Session const&) = delete;
    Session& operator=(Session const&) = delete;
};

}
}

#endif // MIR_FRONTEND_SESSION_H_

==> mir_0.24.0+16.10.20160815.3.orig.tar.gz: include/server/mir/frontend/session.h <==
/*
 * Copyright © 2012 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored By: Robert Carr <racarr@canonical.com>
 */

#ifndef MIR_FRONTEND_SESSION_H_
#define MIR_FRONTEND_SESSION_H_

#include "mir_toolkit/common.h"
#include "mir/frontend/surface_id.h"
#include "mir/graphics/buffer_id.h"
#include "mir/frontend/buffer_stream_id.h"

#include <memory>
#include <string>

namespace mir
{
namespace graphics
{
class DisplayConfiguration;
struct BufferProperties;
class Buffer;
}

namespace frontend
{
class Surface;
class BufferStream;

class Session
{
public:
    virtual ~Session() = default;

    virtual std::shared_ptr<Surface> get_surface(SurfaceId surface) const = 0;

    virtual std::shared_ptr<BufferStream> get_buffer_stream(BufferStreamId stream) const = 0;
    virtual BufferStreamId create_buffer_stream(graphics::BufferProperties const& props) = 0;
    virtual void destroy_buffer_stream(BufferStreamId stream) = 0;

    virtual graphics::BufferID create_buffer(graphics::BufferProperties const& properties) = 0;
    virtual void destroy_buffer(graphics::BufferID) = 0;
    virtual std::shared_ptr<graphics::Buffer> get_buffer(graphics::BufferID) = 0;

    virtual std::string name() const = 0;

    virtual void send_display_config(graphics::DisplayConfiguration const&) = 0;

protected:
    Session() = default;
    Session(Session const&) = delete;
    Session& operator=(Session const&) = delete;
};

}
}

#endif // MIR_FRONTEND_SESSION_H_
